@@ -8,6 +8,7 @@ module Fog
       recognizes(
         :app_name,
         :app_version,
+        :google_auth,
         :google_client,
         :google_client_email,
         :google_client_options,
@@ -18,28 +19,25 @@ module Fog
         :google_json_key_string
       )
 
-      GOOGLE_COMPUTE_API_VERSION     = "v1"
-      GOOGLE_COMPUTE_BASE_URL        = "https://www.googleapis.com/compute/"
+      GOOGLE_COMPUTE_API_VERSION     = "v1".freeze
+      GOOGLE_COMPUTE_BASE_URL        = "https://www.googleapis.com/compute/".freeze
       GOOGLE_COMPUTE_API_SCOPE_URLS  = %w(https://www.googleapis.com/auth/compute
                                           https://www.googleapis.com/auth/devstorage.read_write
                                           https://www.googleapis.com/auth/ndev.cloudman
-                                          https://www.googleapis.com/auth/cloud-platform)
-      GOOGLE_COMPUTE_DEFAULT_NETWORK = "default"
+                                          https://www.googleapis.com/auth/cloud-platform).freeze
+      GOOGLE_COMPUTE_DEFAULT_NETWORK = "default".freeze
       RUNNING = "RUNNING".freeze
       PROVISIONING = "PROVISIONING".freeze
 
       request_path "fog/compute/google/requests"
       request :add_backend_service_backends
       request :add_instance_group_instances
-      request :add_region_view_resources
       request :add_server_access_config
       request :add_target_pool_health_checks
       request :add_target_pool_instances
-      request :add_url_map_host_rules
-      request :add_url_map_path_matchers
-      request :add_zone_view_resources
 
       request :delete_address
+      request :delete_global_address
       request :delete_backend_service
       request :delete_disk
       request :delete_firewall
@@ -51,20 +49,21 @@ module Fog
       request :delete_instance_group
       request :delete_network
       request :delete_region_operation
-      request :delete_region_view
       request :delete_route
       request :delete_server
       request :delete_server_access_config
       request :delete_snapshot
       request :delete_subnetwork
       request :delete_target_http_proxy
+      request :delete_target_https_proxy
       request :delete_target_instance
       request :delete_target_pool
       request :delete_url_map
       request :delete_zone_operation
-      request :delete_zone_view
+      request :delete_ssl_certificate
 
       request :get_address
+      request :get_global_address
       request :get_backend_service
       request :get_backend_service_health
       request :get_disk
@@ -82,57 +81,59 @@ module Fog
       request :get_project
       request :get_region
       request :get_region_operation
-      request :get_region_view
       request :get_route
       request :get_server
       request :get_server_serial_port_output
       request :get_snapshot
       request :get_subnetwork
       request :get_target_http_proxy
+      request :get_target_https_proxy
       request :get_target_instance
       request :get_target_pool
       request :get_target_pool_health
       request :get_url_map
       request :get_zone
       request :get_zone_operation
-      request :get_zone_view
+      request :get_ssl_certificate
 
       request :insert_address
+      request :insert_global_address
       request :insert_backend_service
       request :insert_disk
       request :insert_firewall
-      request :update_firewall
       request :insert_forwarding_rule
       request :insert_global_forwarding_rule
       request :insert_http_health_check
       request :insert_image
       request :insert_instance_group
       request :insert_network
-      request :insert_region_view
       request :insert_route
       request :insert_server
-      request :insert_snapshot
       request :insert_subnetwork
       request :insert_target_http_proxy
+      request :insert_target_https_proxy
       request :insert_target_instance
       request :insert_target_pool
       request :insert_url_map
-      request :insert_zone_view
+      request :insert_ssl_certificate
 
       request :list_addresses
       request :list_aggregated_addresses
       request :list_aggregated_disk_types
       request :list_aggregated_disks
+      request :list_aggregated_forwarding_rules
       request :list_aggregated_instance_groups
       request :list_aggregated_machine_types
       request :list_aggregated_servers
       request :list_aggregated_subnetworks
       request :list_aggregated_target_instances
+      request :list_aggregated_target_pools
       request :list_backend_services
       request :list_disk_types
       request :list_disks
       request :list_firewalls
       request :list_forwarding_rules
+      request :list_global_addresses
       request :list_global_forwarding_rules
       request :list_global_operations
       request :list_http_health_checks
@@ -142,21 +143,22 @@ module Fog
       request :list_machine_types
       request :list_networks
       request :list_region_operations
-      request :list_region_view_resources
-      request :list_region_views
       request :list_regions
       request :list_routes
       request :list_servers
       request :list_snapshots
       request :list_subnetworks
       request :list_target_http_proxies
+      request :list_target_https_proxies
       request :list_target_instances
       request :list_target_pools
       request :list_url_maps
       request :list_zone_operations
-      request :list_zone_view_resources
-      request :list_zone_views
       request :list_zones
+      request :list_ssl_certificates
+
+      request :patch_firewall
+      request :patch_url_map
 
       request :remove_instance_group_instances
       request :remove_target_pool_health_checks
@@ -165,20 +167,35 @@ module Fog
       request :set_common_instance_metadata
       request :set_forwarding_rule_target
       request :set_global_forwarding_rule_target
-      request :set_metadata
       request :set_server_disk_auto_delete
+      request :set_server_metadata
       request :set_server_scheduling
-      request :set_tags
+      request :set_server_tags
+      request :set_snapshot_labels
+      request :set_subnetwork_private_ip_google_access
       request :set_target_http_proxy_url_map
+      request :set_target_https_proxy_ssl_certificates
+      request :set_target_https_proxy_url_map
+      request :set_target_pool_backup
+
+      request :update_firewall
+      request :update_http_health_check
+      request :update_url_map
 
       request :attach_disk
       request :detach_disk
+      request :create_disk_snapshot
+
+      request :expand_subnetwork_ip_cidr_range
       request :reset_server
       request :start_server
       request :stop_server
-      request :update_url_map
+
+      request :invalidate_url_map_cache
       request :validate_url_map
 
+      request :deprecate_image
+
       model_path "fog/compute/google/models"
       model :server
       collection :servers
@@ -186,18 +203,21 @@ module Fog
       model :image
       collection :images
 
-      model :flavor
-      collection :flavors
-
       model :disk
       collection :disks
 
       model :disk_type
       collection :disk_types
 
+      model :machine_type
+      collection :machine_types
+
       model :address
       collection :addresses
 
+      model :global_address
+      collection :global_addresses
+
       model :operation
       collection :operations
 
@@ -237,15 +257,15 @@ module Fog
       model :target_http_proxy
       collection :target_http_proxies
 
+      model :target_https_proxy
+      collection :target_https_proxies
+
       model :url_map
       collection :url_maps
 
       model :global_forwarding_rule
       collection :global_forwarding_rules
 
-      model :resource_view
-      collection :resource_views
-
       model :target_instance
       collection :target_instances
 
@@ -254,6 +274,9 @@ module Fog
 
       model :subnetwork
       collection :subnetworks
+
+      model :ssl_certificate
+      collection :ssl_certificates
     end
   end
 end
