@@ -11,9 +11,8 @@ module Fog
           shared_initialize(options[:google_project], GOOGLE_COMPUTE_API_VERSION, GOOGLE_COMPUTE_BASE_URL)
           options[:google_api_scope_url] = GOOGLE_COMPUTE_API_SCOPE_URLS.join(" ")
 
-          @client = initialize_google_client(options)
-          @compute = @client.discovered_api("compute", api_version)
-          @resourceviews = @client.discovered_api("resourceviews", "v1beta1")
+          initialize_google_client(options)
+          @compute = ::Google::Apis::ComputeV1::ComputeService.new
           @extra_global_projects = options[:google_extra_global_projects] || []
         end
       end
