@@ -20,6 +20,7 @@ module Fog
       # Initializes the Google API Client
       #
       # @param [Hash] options Google API options
+      # @option options [Google::Auth|Signet] :google_auth Manually created authorization to use
       # @option options [String] :google_client_email A @developer.gserviceaccount.com email address to use
       # @option options [String] :google_key_location The location of a pkcs12 key file
       # @option options [String] :google_key_string The content of the pkcs12 key file
@@ -35,43 +36,50 @@ module Fog
       def initialize_google_client(options)
         # NOTE: loaded here to avoid requiring this as a core Fog dependency
         begin
-          require "google/api_client"
+          # Because of how Google API gem was rewritten, we get to do all sorts
+          # of funky things, like this nonsense.
+          require "google/apis/monitoring_#{Fog::Google::Monitoring::GOOGLE_MONITORING_API_VERSION}"
+          require "google/apis/compute_#{Fog::Compute::Google::GOOGLE_COMPUTE_API_VERSION}"
+          require "google/apis/dns_#{Fog::DNS::Google::GOOGLE_DNS_API_VERSION}"
+          require "google/apis/pubsub_#{Fog::Google::Pubsub::GOOGLE_PUBSUB_API_VERSION}"
+          require "google/apis/resourceviews_v1beta2"
+          require "google/apis/sqladmin_#{Fog::Google::SQL::GOOGLE_SQL_API_VERSION}"
+          require "google/apis/storage_#{Fog::Storage::GoogleJSON::GOOGLE_STORAGE_JSON_API_VERSION}"
+          require "googleauth"
         rescue LoadError => error
-          Fog::Logger.warning("Please install the google-api-client gem before using this provider")
+          Fog::Logger.error("Please install the google-api-client (>= 0.9) gem before using this provider")
           raise error
         end
 
-        # User can provide an existing Google API Client
-        client = options[:google_client]
-        return client unless client.nil?
-
-        # Create a signing key
-        signing_key = create_signing_key(options)
-
-        # Validate required arguments
-        unless options[:google_client_email]
-          raise ArgumentError.new("Missing required arguments: google_client_email")
+        # Users can no longer provide their own clients due to rewrite of auth
+        # in https://github.com/google/google-api-ruby-client/ version 0.9.
+        if options[:google_client]
+          raise ArgumentError.new("Deprecated argument no longer works: google_client")
         end
 
+        # They can also no longer use pkcs12 files, because Google's new auth
+        # library doesn't support them either.
+        if options[:google_key_location]
+          raise ArgumentError.new("Deprecated argument no longer works: google_key_location")
+        end
+        if options[:google_key_string]
+          raise ArgumentError.new("Deprecated argument no longer works: google_key_string")
+        end
+
+        # Validate required arguments
         unless options[:google_api_scope_url]
           raise ArgumentError.new("Missing required arguments: google_api_scope_url")
         end
 
-        # Create a new Google API Client
-        new_pk12_google_client(
-          options[:google_client_email],
-          signing_key,
-          options[:google_api_scope_url],
-          options[:app_name],
-          options[:app_version],
-          options[:google_client_options] || {}
-        )
-      end
+        application_name = "fog"
+        unless options[:app_name].nil?
+          application_name = "#{options[:app_name]}/#{options[:app_version] || '0.0.0'} fog"
+        end
 
-      ##
-      # Creates a Google signing key
-      #
-      def create_signing_key(options)
+        ::Google::Apis::ClientOptions.default.application_name = application_name
+        ::Google::Apis::ClientOptions.default.application_version = Fog::Google::VERSION
+
+        auth = nil
         if options[:google_json_key_location] || options[:google_json_key_string]
           if options[:google_json_key_location]
             json_key_location = File.expand_path(options[:google_json_key_location])
@@ -86,54 +94,30 @@ module Fog
           end
 
           options[:google_client_email] = json_key_hash["client_email"]
-          ::Google::APIClient::KeyUtils.load_from_pem(json_key_hash["private_key"], "notasecret")
-        elsif options[:google_key_location] || options[:google_key_string]
-          google_key =
-            if options[:google_key_location]
-              File.expand_path(options[:google_key_location])
-            else
-              options[:google_key_string]
-            end
+          unless options[:google_client_email]
+            raise ArgumentError.new("Missing required arguments: google_client_email")
+          end
 
-          ::Google::APIClient::KeyUtils.load_from_pkcs12(google_key, "notasecret")
+          if ENV["DEBUG"]
+            ::Google::Apis.logger = ::Logger.new(::STDERR)
+            ::Google::Apis.logger.level = ::Logger::DEBUG
+          end
+
+          auth = ::Google::Auth::ServiceAccountCredentials.make_creds(
+            :json_key_io => StringIO.new(json_key_hash.to_json),
+            :scope => options[:google_api_scope_url]
+          )
+        elsif options[:google_auth]
+          auth = options[:google_auth]
         else
-          raise ArgumentError.new("Missing required arguments: google_key_location, google_key_string, " \
-                                  "google_json_key_location or google_json_key_string")
+          raise ArgumentError.new(
+            "Missing required arguments: google_json_key_location, "\
+            "google_json_key_string or google_auth"
+          )
         end
-      end
 
-      ##
-      # Create a Google API Client with a user email and a pkcs12 key
-      #
-      # @param google_client_email [String] A @developer.gserviceaccount.com.
-      #   email address to use
-      # @param signing_key [OpenSSL::PKey] The private key for signing
-      # @param google_api_scope_url [String] Access scope URLs
-      # @param app_name [String] The app name to set in the user agent
-      # @param app_version [String] The app version to set in the user agent
-      # @param google_client_options [Hash] additional options to pass to the
-      #   underlying google client
-      # @return [Google::APIClient] a newly-constructed Google API Client
-      def new_pk12_google_client(google_client_email, signing_key, google_api_scope_url, app_name = nil, app_version = nil, google_client_options = {})
-        application_name = app_name.nil? ? "fog" : "#{app_name}/#{app_version || '0.0.0'} fog"
-        api_client_options = {
-          :application_name => application_name,
-          :application_version => Fog::Google::VERSION
-        }.merge(google_client_options)
-        client = ::Google::APIClient.new(api_client_options)
-
-        client.authorization = Signet::OAuth2::Client.new(
-          :audience => "https://accounts.google.com/o/oauth2/token",
-          :auth_provider_x509_cert_url => "https://www.googleapis.com/oauth2/v1/certs",
-          :client_x509_cert_url => "https://www.googleapis.com/robot/v1/metadata/x509/#{google_client_email}",
-          :issuer => google_client_email,
-          :scope => google_api_scope_url,
-          :signing_key => signing_key,
-          :token_credential_uri => "https://accounts.google.com/o/oauth2/token"
-        )
-        client.authorization.fetch_access_token!
-
-        client
+        ::Google::Apis::RequestOptions.default.authorization = auth
+        auth
       end
 
       ##
