@@ -9,6 +9,7 @@ module Fog
       recognizes(
         :app_name,
         :app_version,
+        :google_auth,
         :google_client,
         :google_client_email,
         :google_client_options,
@@ -19,18 +20,21 @@ module Fog
       )
 
       # https://cloud.google.com/storage/docs/json_api/v1/
-      GOOGLE_STORAGE_JSON_API_VERSION = "v1"
-      GOOGLE_STORAGE_JSON_BASE_URL = "https://www.googleapis.com/storage/"
+      GOOGLE_STORAGE_JSON_API_VERSION = "v1".freeze
+      GOOGLE_STORAGE_JSON_BASE_URL = "https://www.googleapis.com/storage/".freeze
+      GOOGLE_STORAGE_BUCKET_BASE_URL = "https://storage.googleapis.com/".freeze
 
       # TODO: Come up with a way to only request a subset of permissions.
       # https://cloud.google.com/storage/docs/json_api/v1/how-tos/authorizing
-      GOOGLE_STORAGE_JSON_API_SCOPE_URLS = %w(https://www.googleapis.com/auth/devstorage.full_control)
+      GOOGLE_STORAGE_JSON_API_SCOPE_URLS = %w(https://www.googleapis.com/auth/devstorage.full_control).freeze
 
       ##
       # Models
       model_path "fog/storage/google_json/models"
+
       collection :directories
       model :directory
+
       collection :files
       model :file
 
@@ -40,16 +44,19 @@ module Fog
       request :copy_object
       request :delete_bucket
       request :delete_object
+      request :delete_object_url
       request :get_bucket
       request :get_bucket_acl
       request :get_object
       request :get_object_acl
       request :get_object_http_url
       request :get_object_https_url
+      request :get_object_metadata
       request :get_object_url
-      request :head_object
       request :list_buckets
+      request :list_bucket_acl
       request :list_objects
+      request :list_object_acl
       request :put_bucket
       request :put_bucket_acl
       request :put_object
