@@ -13,8 +13,8 @@ module TestCollection
     assert_includes @subject.all.map(&:identity), one.identity
     assert_includes @subject.all.map(&:identity), two.identity
 
-    assert_equal one.identity, @subject.get(one.identity).identity
-    assert_equal two.identity, @subject.get(two.identity).identity
+    assert_equal one.identity, @factory.get(one.identity).identity
+    assert_equal two.identity, @factory.get(two.identity).identity
 
     one.destroy
     two.destroy
@@ -24,7 +24,7 @@ module TestCollection
   end
 
   def test_get_returns_nil_if_resource_does_not_exist
-    assert_nil @subject.get("fog-test-fake-identity")
+    assert_nil @factory.get("fog-test-fake-identity")
   end
 
   def test_enumerable
