@@ -5,9 +5,13 @@ class DisksFactory < CollectionFactory
     super(Fog::Compute[:google].disks, example)
   end
 
+  def get(identity)
+    @subject.get(identity, TEST_ZONE)
+  end
+
   def params
-    {:name => resource_name,
-     :zone_name => TEST_ZONE,
-     :size_gb => TEST_SIZE_GB}
+    { :name => resource_name,
+      :zone_name => TEST_ZONE,
+      :size_gb => TEST_SIZE_GB }
   end
 end
